/*
 * File name: ClientHandler.java
 * Date:      2021/04/14 
 * Author:    Jiri Vokrinek
 */

import java.io.BufferedReader;
import java.util.Date;
import java.net.Socket;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;

class ClientHandlerJava implements Runnable {

    enum Commands {
        TIME("time"),
        BYE("bye"),
        UNKNOWN("");

        final String commandString;

        private Commands(String command) {
            this.commandString = command;
        }

        static Commands getCommand(String commandString) {
            for (Commands command : Commands.values()) {
                if (command.commandString.equalsIgnoreCase(commandString)) {
                    return command;
                }
            }
            return UNKNOWN;
        }
    }

    Socket socket;
    BufferedReader in;
    OutputStreamWriter out;
    int id;

    ClientHandlerJava(Socket iSocket, int iID) throws IOException {
        socket = iSocket;
        id = iID;
        out = new OutputStreamWriter(socket.getOutputStream());
        in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
    }

    public void start() {
        new Thread(this).start();
    }

    void log(String str) {
        System.out.println(str);
    }

    @Override
    public void run() {
        String cID = "client[" + id + "] ";
        try {
            log(cID + "Accepted");
            out.write("Login:\n");
            out.flush();

            log(cID + "Username:" + in.readLine());
            out.write("Password:\n");
            out.flush();

            log(cID + "Password:" + in.readLine());
            out.write("Welcome\n");
            out.flush();

            boolean quit = false;
            while (!quit) {

                switch (Commands.getCommand(in.readLine())) {
                    case TIME:
                        log(cID + "Client sends time");
                        out.write("time is:" + new Date().toString() + "\n");
                        out.flush();
                        break;
                    case BYE:
                        log(cID + "Client sends bye");
                        quit = true;
                        break;
                    default:
                        out.write("Unknown message, bye");
                        out.flush();
                        log(cID + "Unknown message, disconnect");
                        quit = true;
                        break;
                }
            }
            socket.shutdownOutput();
            socket.close();
        } catch (Exception e) {
            System.out.println(cID + "Exception:" + e.getMessage());
            e.printStackTrace();
        }
    }
}
